# SPDX-License-Identifier: AGPL-3.0-or-later
"""
Application manifest for storage.
"""

backup: dict = {}
